#
# spec file for package python-django-rest-knox
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-rest-knox
Version:        5.0.2
Release:        2.1
Summary:        Authentication for Django REST framework
License:        MIT
URL:            https://github.com/James1345/django-rest-knox
Source:         https://github.com/James1345/django-rest-knox/archive/%{version}.tar.gz#/django-rest-knox-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django
Requires:       python-cryptography
Requires:       python-djangorestframework
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module djangorestframework}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Authentication for Django REST framework.

%prep
%autosetup -p1 -n django-rest-knox-%{version}

# knox does not use pyOpenSSL; it uses cryptography.
# pyOpenSSL is a proxy for cryptography in 3.6.0,
# and replaced by cryptography in 4.0.0
sed -i "s/'pyOpenSSL'/'cryptography'/" setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export DJANGO_SETTINGS_MODULE=knox_project.settings
%pytest tests/tests.py

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/knox
%{python_sitelib}/django_rest_knox-%{version}.dist-info

%changelog
* Tue Jun  3 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Tue Oct 22 2024 Dirk Müller <dmueller@suse.com>
- update to 5.0.2:
  * Implement AUTO_REFRESH_MAX_TTL to limit total token lifetime
    when AUTO_REFRESH = True
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 5.0.1:
  * Fix migration: retrieve `TOKEN_MODEL` from `knox_settings`
    instead of Django settings.
  * Tokens created prior to this release will no longer work
  * Fix migration reverse flow, enable migrate 0
  * Various documentation fixes and improvements
  * Drop `cryptography` in favor of hashlib
  * Make custom AuthModel work
  * Token prefix can be set in the setttings
  * Drop support for Django 4.0
  * Add support for Dango 4.2, 5.0 and Python 3.11 and 3.12
  * Cleanup legacy Python 2.0 code
  * Fix isort, flake8 usage for Python 3.10 in the test suite
  * Update Github actions version
  * Upgrade markdown dependency
  * Get rid of the `six` library
  * Add custom login / logout response support
  * Join the jazzband organization
  * Add pre-commit hooks
  * Add tracking of tests code coverage
  * Fix migrations when used in condition with a custom DB
  * Improve typing
  * Use `self.authenticate_header()` in `authenticate()` method
    to get auth header prefix
* Thu Mar 21 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Fri Feb 25 2022 Matej Cepl <mcepl@suse.com>
- Update to 4.2.0:
  - compatibility with Python up to 3.10 and Django up to 4.0
  - Migration: "salt" field of model "AuthToken" is removed
- Remove upstreamed patches:
  - django3.patch
  - remove-django-nose.patch
* Tue Sep 14 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-django-nose.patch:
  * Use pytest-django to run the tests, rather than django-nose.
* Tue Apr 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with Django 3.x:
  * django3.patch
* Sun Apr  5 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.1.0:
  * Expiry format now defaults to whatever is used Django REST framework
  * The behavior can be overriden via EXPIRY_DATETIME_FORMAT setting
  * Fully customizable expiry format via format_expiry_datetime
  * Fully customizable response payload via get_post_response_data
  * Changes have been made to the create() method on the AuthToken model.
    It now returns the model instance and the raw token instead of just
    the token to allow the expiry field to be included in the success response.
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Disable py2 build as it is unresolvable
* Mon May 20 2019 John Vandenberg <jayvdb@gmail.com>
- Add non-updating note to the SPEC file
* Wed Apr 10 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v3.6.0
